@@ -17,19 +17,20 @@
 */
 
 
-#ifndef _XMMS_MAIN_H_
+#ifndef _MAIN_H_
 
-#define _XMMS_MAIN_H_
+#define _MAIN_H_
 
 #define PACKAGE "audtty"
-#define VERSION "0.1"
-#define COPYRIGHT "Copyright 2005 Kiyoshi Aman <kiyoshi.aman@gmail.com>" 
+#define VERSION "0.1.10a"
+#define COPYRIGHT "Copyright 2009 Chris Taylor <chris@code-monkeys.org>"
 
 #define CONFIG_MAX_LINE_LENGTH 1024
 #define SLEEP_TIME 500000
 
-#include <ncurses.h>
+#include <ncursesw/ncurses.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 
 #ifndef COLOR_DEFAULT
 #define COLOR_DEFAULT -1
@@ -39,19 +40,20 @@ typedef struct {
 	WINDOW *status;
 	WINDOW *title;
 	WINDOW *list;
-	int term_resized;
+	gint term_resized;
 } windows;
 
 typedef struct {
-	int show_numbers;
-	int read_length;
-	int read_title;
-	int read_all;
+	gint show_numbers;
+	gint read_length;
+	gint read_title;
+	gint read_all;
 } prefs;
 
 void paint_playback(void);
 void paint_songinfo(void);
-void mvwtitledhline(WINDOW *win, int y, char *label);
+void mvwtitledhline(WINDOW *win, gint y, gchar *label);
 void resize_windows(void);
+void mainwin_repaint(void);
 
 #endif
